@@ -46,7 +46,7 @@ void MosUtilities::MosFreeUserFeatureValueString(PMOS_USER_FEATURE_VALUE_STRING
             if (pUserString->pStringData)
             {
                 MOS_FreeMemAndSetNull(pUserString->pStringData);
-                m_mosMemAllocFakeCounter--;
+                MosAtomicDecrement(m_mosMemAllocFakeCounter);
             }
             pUserString->uSize = 0;
         }
@@ -466,7 +466,7 @@ MOS_STATUS MosUtilities::MosAssignUserFeatureValueData(
                 MOS_OS_ASSERTMESSAGE("Failed to allocate memory.");
                 return MOS_STATUS_NULL_POINTER;
             }
-            m_mosMemAllocFakeCounter++;
+            MosAtomicIncrement(m_mosMemAllocFakeCounter);
             eStatus = MosSecureStrcpy(
                 pDstData->StringData.pStringData,
                 pDstData->StringData.uSize,
@@ -486,8 +486,13 @@ MOS_STATUS MosUtilities::MosAssignUserFeatureValueData(
             pDstData->MultiStringData.uCount          = 0;
             return MOS_STATUS_NULL_POINTER;
         }
+        MosAtomicIncrement(m_mosMemAllocFakeCounter);
         if ((pData != nullptr) && (strlen(pData) != 0))
         {
+            if (!pDstData->MultiStringData.pMultStringData)
+            {
+                MosAtomicIncrement(m_mosMemAllocFakeCounter);
+            }
             MOS_SafeFreeMemory(pDstData->MultiStringData.pMultStringData);
             pDstData->MultiStringData.pMultStringData = (char *)MOS_AllocAndZeroMemory(strlen(pData) + 1);
             if (pDstData->MultiStringData.pMultStringData == nullptr)
@@ -582,6 +587,7 @@ MOS_STATUS MosUtilities::MosDestroyUserFeatureData(PMOS_USER_FEATURE_VALUE_DATA
             MosFreeUserFeatureValueString(&pData->MultiStringData.pStrings[ui]);
         }
         MOS_SafeFreeMemory(pData->MultiStringData.pStrings);
+        MosAtomicDecrement(m_mosMemAllocFakeCounter);
         pData->MultiStringData.pStrings = nullptr;
         pData->MultiStringData.pMultStringData = nullptr;
         pData->MultiStringData.uSize = 0;
@@ -933,7 +939,7 @@ MOS_STATUS MosUtilities::MosUserFeatureReadValueString(
     {
         if (!pFeatureValue->Value.StringData.pStringData)
         {
-            m_mosMemAllocFakeCounter++;
+            MosAtomicIncrement(m_mosMemAllocFakeCounter);
         }
 
         if (pFeatureValue->Value.StringData.uSize < strlen(pcTmpStr) + 1)
@@ -1003,9 +1009,12 @@ MOS_STATUS MosUtilities::MosUserFeatureReadValueMultiString(
 
     if (strlen(pcTmpStr) > 0)
     {
+        if (!pFeatureValue->Value.MultiStringData.pMultStringData)
+        {
+            MosAtomicIncrement(m_mosMemAllocFakeCounter);
+        }
         MOS_SafeFreeMemory(pFeatureValue->Value.MultiStringData.pMultStringData);
         pFeatureValue->Value.MultiStringData.pMultStringData = (char *)MOS_AllocAndZeroMemory(strlen(pcTmpStr) + 1);
-        m_mosMemAllocFakeCounter++;
         if (pFeatureValue->Value.MultiStringData.pMultStringData == nullptr)
         {
             MOS_OS_ASSERTMESSAGE("Failed to allocate memory.");
