@@ -150,6 +150,7 @@ MOS_STATUS DecodeScalabilityMultiPipeNext::Initialize(const MediaScalabilityOpti
     {
         MOS_STATUS status = m_osInterface->pfnVirtualEngineInit(m_osInterface, &m_veHitParams, veInitParms);
         SCALABILITY_CHK_STATUS_MESSAGE_RETURN(status, "Virtual Engine Init failed");
+        m_veInterface = m_osInterface->pVEInterf;
         if (m_osInterface->osStreamState && m_osInterface->osStreamState->virtualEngineInterface)
         {
             // we set m_veState here when pOsInterface->apoMosEnabled is true
@@ -217,6 +218,8 @@ MOS_STATUS DecodeScalabilityMultiPipeNext::Destroy()
         MOS_Delete(m_scalabilityOption);
     }
 
+    m_osInterface->pfnDestroyVeInterface(&m_veInterface);
+
     for (auto &semaphoreBufferVec : m_resSemaphoreAllPipes)
     {
         for (auto &semaphoreBuffer : semaphoreBufferVec)
@@ -340,8 +343,8 @@ MOS_STATUS DecodeScalabilityMultiPipeNext::GetCmdBuffer(PMOS_COMMAND_BUFFER cmdB
     if (m_osInterface->apoMosEnabled)
     {
         SCALABILITY_CHK_NULL_RETURN(m_osInterface->osStreamState);
-        SCALABILITY_CHK_STATUS_RETURN(MosInterface::SetVeSubmissionType(
-            m_osInterface->osStreamState, &scdryCmdBuffer, m_phase->GetSubmissionType()));
+        SCALABILITY_CHK_NULL_RETURN(m_osInterface->osStreamState->virtualEngineInterface);
+        SCALABILITY_CHK_STATUS_RETURN(m_osInterface->osStreamState->virtualEngineInterface->SetSubmissionType(&scdryCmdBuffer, m_phase->GetSubmissionType()));
     }
     else
     {
@@ -393,6 +396,7 @@ MOS_STATUS DecodeScalabilityMultiPipeNext::SetHintParams()
                                  (!decodeScalabilityOption->IsFESeparateSubmission());
     veParams.bScalableMode     = true;
 
+    m_osInterface->pVEInterf = m_veInterface;
     eStatus = m_osInterface->pfnSetHintParams(m_osInterface, &veParams);
 
     return eStatus;
@@ -403,8 +407,9 @@ MOS_STATUS DecodeScalabilityMultiPipeNext::PopulateHintParams(PMOS_COMMAND_BUFFE
     SCALABILITY_FUNCTION_ENTER;
     SCALABILITY_CHK_NULL_RETURN(cmdBuffer);
     SCALABILITY_CHK_NULL_RETURN(m_veHitParams);
+    SCALABILITY_CHK_NULL_RETURN(m_osInterface);
 
-    PMOS_CMD_BUF_ATTRI_VE attriVe  = MosInterface::GetAttributeVeBuffer(cmdBuffer);
+    PMOS_CMD_BUF_ATTRI_VE attriVe  = m_osInterface->pfnGetAttributeVeBuffer(cmdBuffer);
     if (attriVe)
     {
         attriVe->VEngineHintParams     = *(m_veHitParams);
