@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2019-2021, Intel Corporation
+* Copyright (c) 2019-2023, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -62,6 +62,7 @@ MOS_STATUS Av1BasicFeature::Init(void *setting)
         MediaUserSetting::Group::Sequence,
         m_osInterface->pOsContext);
     m_enableSWStitching = outValue.Get<bool>();
+    m_enableTileStitchByHW = !m_enableSWStitching;
 
     ReadUserSettingForDebug(
         m_userSettingPtr,
@@ -224,6 +225,10 @@ MOS_STATUS Av1BasicFeature::Update(void *params)
 
     ENCODE_CHK_STATUS_RETURN(CheckLrParams(*m_av1PicParams));
 
+    m_enableCDEF = !(IsFrameLossless(*m_av1PicParams) 
+        || m_av1PicParams->PicFlags.fields.allow_intrabc
+        || !(m_av1SeqParams->CodingToolFlags.fields.enable_cdef));
+
     // Update reference frames
     ENCODE_CHK_STATUS_RETURN(m_ref.Update());
 
@@ -455,8 +460,9 @@ MOS_STATUS Av1BasicFeature::GetSurfaceMmcInfo(PMOS_SURFACE surface, MOS_MEMCOMP_
     ENCODE_FUNC_CALL();
 
     ENCODE_CHK_NULL_RETURN(surface);
-    ENCODE_CHK_NULL_RETURN(m_mmcState);
 
+#ifdef _MMC_SUPPORTED
+    ENCODE_CHK_NULL_RETURN(m_mmcState);
     if (m_mmcState->IsMmcEnabled())
     {
         ENCODE_CHK_STATUS_RETURN(m_mmcState->GetSurfaceMmcState(surface, &mmcState));
@@ -466,6 +472,7 @@ MOS_STATUS Av1BasicFeature::GetSurfaceMmcInfo(PMOS_SURFACE surface, MOS_MEMCOMP_
     {
         mmcState = MOS_MEMCOMP_DISABLED;
     }
+#endif
 
     return MOS_STATUS_SUCCESS;
 }
@@ -649,6 +656,12 @@ MHW_SETPAR_DECL_SRC(VDENC_PIPE_MODE_SELECT, Av1BasicFeature)
         params.tailPointerReadFrequency = 0x50;
     }
 
+    if (m_dualEncEnable)
+    {
+        params.scalabilityMode = true;
+        params.tileBasedReplayMode = true;
+    }
+
     params.frameStatisticsStreamOut = IsRateControlBrc(m_av1SeqParams->RateControlMethod) || m_adaptiveRounding;
 
     return MOS_STATUS_SUCCESS;
@@ -755,6 +768,8 @@ MHW_SETPAR_DECL_SRC(VDENC_DS_REF_SURFACE_STATE, Av1BasicFeature)
 
 MHW_SETPAR_DECL_SRC(VDENC_PIPE_BUF_ADDR_STATE, Av1BasicFeature)
 {
+#ifdef _MMC_SUPPORTED    
+    ENCODE_CHK_NULL_RETURN(m_mmcState);
     if (m_mmcState->IsMmcEnabled())
     {
         params.mmcEnabled = true;
@@ -767,6 +782,7 @@ MHW_SETPAR_DECL_SRC(VDENC_PIPE_BUF_ADDR_STATE, Av1BasicFeature)
         params.mmcStateRaw          = MOS_MEMCOMP_DISABLED;
         params.compressionFormatRaw = GMM_FORMAT_INVALID;
     }
+#endif
 
     params.surfaceRaw                    = m_rawSurfaceToEnc;
     params.surfaceDsStage1               = m_8xDSSurface;
@@ -881,11 +897,8 @@ MHW_SETPAR_DECL_SRC(AVP_PIC_STATE, Av1BasicFeature)
     params.reducedTxSetUsed     = m_av1PicParams->PicFlags.fields.reduced_tx_set_used ? true : false;
     params.txMode               = m_av1PicParams->dwModeControlFlags.fields.tx_mode;
     params.skipModePresent      = m_av1PicParams->dwModeControlFlags.fields.skip_mode_present ? true : false;
-
-    // overridden when in frame-level coded lossless or when intraBC is enabled
-    params.enableCDEF = !(params.codedLossless || m_av1PicParams->PicFlags.fields.allow_intrabc 
-        || !(m_av1SeqParams->CodingToolFlags.fields.enable_cdef));
-
+    params.enableCDEF           = m_enableCDEF;
+    
     for (uint8_t i = 0; i < 7; i++)
         params.globalMotionType[i] = static_cast<uint8_t>(m_av1PicParams->wm[i].wmtype);
 
@@ -939,10 +952,10 @@ MHW_SETPAR_DECL_SRC(AVP_PIC_STATE, Av1BasicFeature)
     params.sbMaxSizeReportMask = false;
     params.sbMaxBitSizeAllowed = 0;
 
-    params.autoBistreamStitchingInHardware = !m_enableSWStitching;
+    params.autoBistreamStitchingInHardware = !m_enableSWStitching && !m_dualEncEnable;
 
     // special fix to avoid zero padding for low resolution/bitrates and restore up to 20% BdRate quality
-    if ((m_av1PicParams->tile_cols * m_av1PicParams->tile_rows == 1) || m_enableSWStitching)
+    if ((m_av1PicParams->tile_cols * m_av1PicParams->tile_rows == 1) || m_dualEncEnable)
     {
         params.minFramSize = 0;
         params.minFramSizeUnits                = 0;
@@ -1052,6 +1065,8 @@ MHW_SETPAR_DECL_SRC(AVP_PIPE_BUF_ADDR_STATE, Av1BasicFeature)
     params.postCDEFpixelsBuffer = postCdefSurface;
 
     // code from SetAvpPipeBufAddr
+ #ifdef _MMC_SUPPORTED    
+    ENCODE_CHK_NULL_RETURN(m_mmcState);
     if (m_mmcState->IsMmcEnabled())
     {
         ENCODE_CHK_STATUS_RETURN(m_mmcState->GetSurfaceMmcState(const_cast<PMOS_SURFACE>(&m_reconSurface), &params.mmcStatePreDeblock));
@@ -1064,6 +1079,7 @@ MHW_SETPAR_DECL_SRC(AVP_PIPE_BUF_ADDR_STATE, Av1BasicFeature)
         params.mmcStateRawSurf       = MOS_MEMCOMP_DISABLED;
         params.postCdefSurfMmcState  = MOS_MEMCOMP_DISABLED;
     }
+#endif
 
     params.decodedPic              = const_cast<PMOS_SURFACE>(&m_reconSurface);
     params.decodedPic->MmcState    = params.mmcStatePreDeblock;  // This is for MMC report only
