@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2019, Intel Corporation
+* Copyright (c) 2019 - 2023, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -54,11 +54,7 @@ public:
         Av1VdencPacket,
         Av1PakIntegrate,
         Av1BackAnnotation,
-#if _MEDIA_RESERVED
-#define AV1_PACKET_IDS_EXT
-#include "encode_av1_pipeline_ext.h"
-#undef AV1_PACKET_IDS_EXT
-#endif
+        Av1Superres
     };
 
 protected:
@@ -106,6 +102,8 @@ protected:
         uint32_t                                  index);
 #endif
 
+    bool m_dualEncEnable = false;
+
 MEDIA_CLASS_DEFINE_END(encode__Av1Pipeline)
 };
 
