@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2009-2022, Intel Corporation
+* Copyright (c) 2009-2023, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -34,31 +34,22 @@
 #include "mos_interface.h"
 #include "media_user_setting.h"
 
-PerfUtility* g_perfutility = PerfUtility::getInstance();
-
-AutoPerfUtility::AutoPerfUtility(std::string tag, std::string comp, std::string level)
-{
-    if (PERFUTILITY_IS_ENABLED(comp, level))
-    {
-        g_perfutility->startTick(tag);
-        autotag = tag;
-        bEnable = true;
-    }
-}
-
-AutoPerfUtility::~AutoPerfUtility()
-{
-    if (bEnable)
-    {
-        g_perfutility->stopTick(autotag);
-    }
-}
-
 #if MOS_MEDIASOLO_SUPPORTED
 void *   _MOS_INTERFACE::pvSoloContext = nullptr; 
 uint32_t _MOS_INTERFACE::soloRefCnt = 0;
 #endif  // MOS_MEDIASOLO_SUPPORTED
 
+extern MhwCpInterface* Create_MhwCpInterface(PMOS_INTERFACE osInterface);
+extern void Delete_MhwCpInterface(MhwCpInterface* mhwInterface);
+
+#if !EMUL
+extern CpCopyInterface* Create_CpCopyInterface(MOS_CONTEXT_HANDLE osDriverContext, MOS_STATUS& status);
+extern void Delete_CpCopyInterface(CpCopyInterface* cpCopyInterface);
+
+extern CodechalSecureDecodeInterface* Create_SecureDecodeInterface(CodechalSetting* codechalSettings, CodechalHwInterface* hwInterfaceInput);
+extern void Delete_SecureDecodeInterface(CodechalSecureDecodeInterface* codechalSecureDecodeInterface);
+#endif
+
 //! \brief    Unified OS add command to command buffer
 //! \details  Offset returned is dword aligned but size requested can be byte aligned
 //! \param    PMOS_COMMAND_BUFFER pCmdBuffer
@@ -623,12 +614,14 @@ const char *GpuCmdResInfoDump::GetTileType(MOS_TILE_TYPE tileType) const
 //! \details  OS Interface initilization
 //! \param    PMOS_INTERFACE pOsInterface
 //!           [in/out] Pointer to OS Interface
-//! \param    PMOS_CONTEXT pOsDriverContext
+//! \param    MOS_CONTEXT_HANDLE osDriverContext
 //!           [in] Pointer to Driver context
+//! \param    MOS_COMPONENT component
+//!           [in] OS component
 //! \return   MOS_STATUS
 //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
 //!
-MOS_STATUS Mos_InitInterface(
+MOS_STATUS Mos_InitOsInterface(
     PMOS_INTERFACE     pOsInterface,
     MOS_CONTEXT_HANDLE osDriverContext,
     MOS_COMPONENT      component)
@@ -647,6 +640,38 @@ MOS_STATUS Mos_InitInterface(
     pOsInterface->pfnVirtualEngineSupported             = Mos_CheckVirtualEngineSupported;
     pOsInterface->pfnGetResourceCachePolicyMemoryObject = Mos_GetResourceCachePolicyMemoryObject;
 
+    pOsInterface->pfnIsAsyncDevice                      = Mos_IsAsyncDevice;
+    pOsInterface->pfnMosFmtToOsFmt                      = Mos_MosFmtToOsFmt;
+    pOsInterface->pfnOsFmtToMosFmt                      = Mos_OsFmtToMosFmt;
+    pOsInterface->pfnMosFmtToGmmFmt                     = Mos_MosFmtToGmmFmt;
+    pOsInterface->pfnGmmFmtToMosFmt                     = Mos_GmmFmtToMosFmt;
+    pOsInterface->pfnWaitForCmdCompletion               = Mos_WaitForCmdCompletion;
+    pOsInterface->pfnGetResourceArrayIndex              = Mos_GetResourceArrayIndex;
+    pOsInterface->pfnSetupAttributeVeBuffer             = Mos_SetupAttributeVeBuffer;
+    pOsInterface->pfnGetAttributeVeBuffer               = Mos_GetAttributeVeBuffer;
+    pOsInterface->pfnSetupCurrentCmdListAndPool         = Mos_SetupCurrentCmdListAndPool;
+    pOsInterface->pfnGmmToMosResourceUsageType          = Mos_GmmToMosResourceUsageType;
+    pOsInterface->pfnGetAdapterInfo                     = Mos_GetAdapterInfo;
+    pOsInterface->pfnIsCompressibelSurfaceSupported     = Mos_IsCompressibelSurfaceSupported;
+    pOsInterface->pfnDestroyVirtualEngineState          = Mos_DestroyVirtualEngineState;
+    pOsInterface->pfnGetResourceHandle                  = Mos_GetResourceHandle;
+    pOsInterface->pfnGetRtLogResourceInfo               = Mos_GetRtLogResourceInfo;
+    pOsInterface->pfnResetResource                      = Mos_ResetMosResource;
+
+    pOsInterface->pfnCreateMhwCpInterface               = Create_MhwCpInterface;
+    pOsInterface->pfnDeleteMhwCpInterface               = Delete_MhwCpInterface;
+#if !EMUL
+    pOsInterface->pfnCreateCpCopyInterface              = Create_CpCopyInterface;
+    pOsInterface->pfnDeleteCpCopyInterface              = Delete_CpCopyInterface;
+
+    pOsInterface->pfnCreateSecureDecodeInterface        = Create_SecureDecodeInterface;
+    pOsInterface->pfnDeleteSecureDecodeInterface        = Delete_SecureDecodeInterface;
+#endif
+#if (_DEBUG || _RELEASE_INTERNAL)
+    pOsInterface->pfnGetVeEngineCount                   = Mos_GetVeEngineCount;
+    pOsInterface->pfnGetEngineLogicIdByIdx              = Mos_GetEngineLogicId;
+#endif
+
     pOsInterface->Component                 = component;
     pOsInterface->modulizedMosEnabled       = true;
     pOsInterface->osContextPtr              = nullptr;
@@ -1000,5 +1025,128 @@ MEMORY_OBJECT_CONTROL_STATE Mos_GetResourceCachePolicyMemoryObject(
     return memObjCtrlState;
 }
 
+bool Mos_IsAsyncDevice(
+    MOS_STREAM_HANDLE   streamState)
+{
+    return MosInterface::IsAsyncDevice(streamState);
+}
+
+uint32_t Mos_MosFmtToOsFmt(
+    MOS_FORMAT          format)
+{
+    return MosInterface::MosFmtToOsFmt(format);
+}
+
+MOS_FORMAT Mos_OsFmtToMosFmt(
+    uint32_t            format)
+{
+    return MosInterface::OsFmtToMosFmt(format);
+}
+
+GMM_RESOURCE_FORMAT Mos_MosFmtToGmmFmt(
+    MOS_FORMAT          format)
+{
+    return MosInterface::MosFmtToGmmFmt(format);
+}
+
+MOS_FORMAT Mos_GmmFmtToMosFmt(
+    GMM_RESOURCE_FORMAT format)
+{
+    return MosInterface::GmmFmtToMosFmt(format);
+}
+
+MOS_STATUS Mos_WaitForCmdCompletion(
+    MOS_STREAM_HANDLE   streamState,
+    GPU_CONTEXT_HANDLE  gpuCtx)
+{
+    return MosInterface::WaitForCmdCompletion(streamState, gpuCtx);
+}
+
+uint32_t Mos_GetResourceArrayIndex(
+    PMOS_RESOURCE       resource)
+{
+    return MosInterface::GetResourceArrayIndex(resource);
+}
+
+MOS_STATUS Mos_SetupAttributeVeBuffer(
+    MOS_STREAM_HANDLE       streamState,
+    COMMAND_BUFFER_HANDLE   cmdBuffer)
+{
+    return MosInterface::SetupAttributeVeBuffer(streamState, cmdBuffer);
+}
+
+MOS_CMD_BUF_ATTRI_VE *Mos_GetAttributeVeBuffer(
+    COMMAND_BUFFER_HANDLE   cmdBuffer)
+{
+    return MosInterface::GetAttributeVeBuffer(cmdBuffer);
+}
+
+MOS_STATUS Mos_SetupCurrentCmdListAndPool(
+    PMOS_INTERFACE          osInterface,
+    MOS_STREAM_HANDLE       streamState)
+{
+    return MosInterface::SetupCurrentCmdListAndPoolFromOsInterface(osInterface, streamState);
+}
+
+MOS_HW_RESOURCE_DEF Mos_GmmToMosResourceUsageType(
+    GMM_RESOURCE_USAGE_TYPE gmmResUsage)
+{
+    return MosInterface::GmmToMosResourceUsageType(gmmResUsage);
+}
+
+ADAPTER_INFO *Mos_GetAdapterInfo(
+    MOS_STREAM_HANDLE       streamState)
+{
+    return MosInterface::GetAdapterInfo(streamState);
+}
+
+bool Mos_IsCompressibelSurfaceSupported(
+    MEDIA_FEATURE_TABLE     *skuTable)
+{
+    return MosInterface::IsCompressibelSurfaceSupported(skuTable);
+}
+
+MOS_STATUS Mos_DestroyVirtualEngineState(
+    MOS_STREAM_HANDLE       streamState)
+{
+    return MosInterface::DestroyVirtualEngineState(streamState);
+}
+
+uint64_t Mos_GetResourceHandle(
+    MOS_STREAM_HANDLE       streamState,
+    PMOS_RESOURCE           osResource)
+{
+    return MosInterface::GetResourceHandle(streamState, osResource);
+}
+
+void Mos_GetRtLogResourceInfo(
+    MOS_STREAM_HANDLE       streamState,
+    PMOS_RESOURCE           &osResource,
+    uint32_t                &size)
+{
+    return MosInterface::GetRtLogResourceInfo(streamState, osResource, size);
+}
+
+void Mos_ResetMosResource(
+    PMOS_RESOURCE           resource)
+{
+    return MosInterface::MosResetResource(resource);
+}
+
+#if (_DEBUG || _RELEASE_INTERNAL)
+uint8_t Mos_GetVeEngineCount(
+    MOS_STREAM_HANDLE       streamState)
+{
+    return MosInterface::GetVeEngineCount(streamState);
+}
+
+uint8_t Mos_GetEngineLogicId(
+    MOS_STREAM_HANDLE       streamState,
+    uint32_t                instanceIdx)
+{
+    return MosInterface::GetEngineLogicId(streamState, instanceIdx);
+}
+#endif
+
 void *MosStreamState::pvSoloContext = nullptr; 
 
