@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2018-2021, Intel Corporation
+* Copyright (c) 2018-2023, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -40,8 +40,6 @@
 #include "UmdStateSeparation.h"
 #endif
 
-
-
 #define MAX_NAME_LEN            100
 
 #define VPHAL_DUMP_OUTPUT_FOLDER                "\\vphaldump\\"
@@ -64,8 +62,8 @@
 #define VP_SURFACE_DUMP(                                       \
     debuginterface, surf, frameCntr, layerCntr, loc)           \
     if (debuginterface)                                        \
-        VP_DEBUG_CHK_STATUS(debuginterface->DumpVpSurface(     \
-           surf, frameCntr, layerCntr, loc));
+        debuginterface->DumpVpSurface(                         \
+           surf, frameCntr, layerCntr, loc);
 
 //------------------------------------------------------------------------------
 // Dump array of surfaces
@@ -275,6 +273,19 @@ public:
         bool                        bNoDecompWhenLock,
         uint8_t*                    pData);
 
+    virtual MOS_STATUS CopyThenLockResources(
+        PMOS_INTERFACE               pOsInterface,
+        PVPHAL_SURFACE               pSurface,
+        bool                         hasAuxSurf,
+        bool                         enableAuxDump,
+        PMOS_LOCK_PARAMS             pLockFlags,
+        PMOS_RESOURCE                pLockedResource,
+        VPHAL_SURF_DUMP_SURFACE_DEF *pPlanes,
+        uint32_t                    *pdwNumPlanes,
+        uint32_t                    *pdwSize,
+        uint8_t                     *&pData,
+        const char                  *psPathPrefix = nullptr,
+        uint64_t                     iCounter = 0);
 
     VPHAL_SURF_DUMP_SPEC    m_dumpSpec;
 
@@ -346,6 +357,8 @@ public:
     //!
     void GetSurfaceDumpSpec();
 
+    void GetSurfaceDumpSpecForVPSolo(VPHAL_SURF_DUMP_SPEC * pDumpSpec, MediaUserSetting::Value outValue);
+
 protected:
     //!
     //! \brief    Convert a string to loc enum type
@@ -424,6 +437,7 @@ private:
         uint32_t*                           pdwSize,
         bool                                auxEnable,
         bool                                isDeswizzled);
+
     //!
     //! \brief    Parse dump location
     //! \details  Take dump location strings and break down into individual post-
@@ -606,6 +620,15 @@ private:
     //!
     const char * GetTileTypeStr(MOS_TILE_TYPE tile_type);
 
+    //!
+    //! \brief    Gets Debug Tile Mode String
+    //! \param    [in] tilemode
+    //!           Mos tile mode
+    //! \return   const char *
+    //!           String of the tile type
+    //!
+    const char *GetTileModeGMMStr(MOS_TILE_MODE_GMM tile_mode);
+
     //!
     //! \brief    Gets Debug Surface Type String
     //! \param    [in] component
