@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2018-2022, Intel Corporation
+* Copyright (c) 2018-2023, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -22,14 +22,8 @@
 #ifndef __VP_UTILS_H__
 #define __VP_UTILS_H__
 
-#include <mutex>
 #include "mos_util_debug.h"
-#include "mos_os.h"
 #include "vp_common.h"
-#include "media_class_trace.h"
-#include "hal_kerneldll_next.h"
-#include <functional>
-#include <algorithm>
 
 using MosFormatArray = std::vector<MOS_FORMAT>;
 
@@ -136,6 +130,9 @@ using MosFormatArray = std::vector<MOS_FORMAT>;
 #define VP_DEBUG_CHK_STATUS(_stmt)                                                \
     MOS_CHK_STATUS(MOS_COMPONENT_VP, MOS_VP_SUBCOMP_DEBUG, _stmt)
 
+#define VP_DEBUG_CHK_STATUS_RETURN(_stmt)                                         \
+    MOS_CHK_STATUS_RETURN(MOS_COMPONENT_VP, MOS_VP_SUBCOMP_DEBUG, _stmt)
+
 #define VP_DEBUG_CHK_NULL(_ptr)                                                   \
     MOS_CHK_NULL(MOS_COMPONENT_VP, MOS_VP_SUBCOMP_DEBUG, _ptr)
 
@@ -265,44 +262,66 @@ protected:
 #define VP_FUNC_CALL()
 #endif
 
+#define __VPHAL_VEBOX_OUTPUTPIPE_MODE                                   "VPOutputPipe Mode"
+#define __VPHAL_VEBOX_FEATURE_INUSE                                     "VeBox Feature In use"
+#define __VPHAL_VEBOX_DISABLE_SFC                                       "Disable SFC"
+#define __MEDIA_USER_FEATURE_VALUE_SFC_OUTPUT_DTR_DISABLE               "Disable SFC DTR"
+#define __MEDIA_USER_FEATURE_VALUE_SFC_OUTPUT_CENTERING_DISABLE         "SFC Output Centering Disable"
+#define __VPHAL_BYPASS_COMPOSITION                                      "Bypass Composition"
+#define __MEDIA_USER_FEATURE_VALUE_VEBOX_TGNE_ENABLE_VP                 "Enable Vebox GNE"
+
+#define __VPHAL_RNDR_SSD_CONTROL                                        "SSD Control"
+#define __MEDIA_USER_FEATURE_VALUE_CSC_COEFF_PATCH_MODE_DISABLE         "CSC Patch Mode Disable"
+#define __MEDIA_USER_FEATURE_VALUE_DISABLE_DN                           "Disable Dn"
+#define __MEDIA_USER_FEATURE_VALUE_DISABLE_PACKET_REUSE                 "Disable PacketReuse"
+#define __MEDIA_USER_FEATURE_VALUE_ENABLE_PACKET_REUSE_TEAMS_ALWAYS     "Enable PacketReuse Teams mode Always"
+#define __MEDIA_USER_FEATURE_VALUE_FORCE_ENABLE_VEBOX_OUTPUT_SURF       "Force Enable Vebox Output Surf"
+
+#define __VPHAL_HDR_LUT_MODE                                            "HDR Lut Mode"
+#define __VPHAL_HDR_GPU_GENERTATE_3DLUT                                 "HDR GPU generate 3DLUT"
+#define __VPHAL_HDR_DISABLE_AUTO_MODE                                   "Disable HDR Auto Mode"
+#define __VPHAL_HDR_SPLIT_FRAME_PORTIONS                                "VPHAL HDR Split Frame Portions"
+#define __MEDIA_USER_FEATURE_VALUE_VPP_APOGEIOS_ENABLE                  "VP Apogeios Enabled"
+#define __VPHAL_PRIMARY_MMC_COMPRESSMODE                                "VP Primary Surface Compress Mode"
+#define __VPHAL_RT_MMC_COMPRESSMODE                                     "VP RT Compress Mode"
+#define __VPHAL_RT_Cache_Setting                                        "VP RT Cache Setting"
+
+#if (_DEBUG || _RELEASE_INTERNAL)
+#define __VPHAL_RT_Old_Cache_Setting                                    "VP RT Old Cache Setting"
+#define __VPHAL_ENABLE_COMPUTE_CONTEXT                                  "VP Enable Compute Context"
+#define __VPHAL_RNDR_SCOREBOARD_CONTROL                                 "SCOREBOARD Control"
+#define __VPHAL_RNDR_CMFC_CONTROL                                       "CMFC Control"
+#define __VPHAL_ENABLE_1K_1DLUT                                         "Enable 1K 1DLUT"
+#define __VPHAL_VEBOX_HDR_MODE                                          "VeboxHDRMode"
+#define __VPHAL_HDR_ENABLE_QUALITY_TUNING                               "VPHAL HDR Enable Quality Tuning"
+#define __VPHAL_HDR_ENABLE_KERNEL_DUMP                                  "VPHAL HDR Enable Kernel Dump"
+#define __VPHAL_HDR_H2S_RGB_TM                                          "VPHAL H2S TM RGB Based"
+
+// Compression
+#define __VPHAL_MMC_ENABLE                                              "VP MMC In Use"
+#define __VPHAL_RT_MMC_COMPRESSIBLE                                     "VP RT Compressible"
+#define __VPHAL_PRIMARY_MMC_COMPRESSIBLE                                "VP Primary Surface Compressible"
+
+#define __VPHAL_RNDR_FORCE_VP_DECOMPRESSED_OUTPUT                       "FORCE VP DECOMPRESSED OUTPUT"
+#define __VPHAL_COMP_8TAP_ADAPTIVE_ENABLE                               "8-TAP Enable"
+#define __VPHAL_VEBOX_FORCE_VP_MEMCOPY_OUTPUTCOMPRESSED                 "Force VP Memorycopy Outputcompressed"
+#define __VPHAL_ENABLE_SFC_NV12_P010_LINEAR_OUTPUT                      "Enable SFC NV12 P010 Linear Output"
+#define __VPHAL_ENABLE_SFC_RGBP_RGB24_OUTPUT                            "Enable SFC RGBP RGB24 Output"
+
+#define __VPHAL_DBG_PARAM_DUMP_OUTFILE_KEY_NAME                         "outxmlLocation"
+#define __VPHAL_DBG_PARAM_DUMP_START_FRAME_KEY_NAME                     "startxmlFrame"
+#define __VPHAL_DBG_PARAM_DUMP_END_FRAME_KEY_NAME                       "endxmlFrame"
+#define __VPHAL_DBG_DUMP_OUTPUT_DIRECTORY                               "Vphal Debug Dump Output Directory"
+#define __VPHAL_DBG_PARA_DUMP_ENABLE_SKUWA_DUMP                         "enableSkuWaDump"
+
+#define __MEDIA_USER_FEATURE_VALUE_INTER_FRAME_MEMORY_NINJA_START_COUNTER "InterFrameNinjaStartCounter"
+#define __MEDIA_USER_FEATURE_VALUE_INTER_FRAME_MEMORY_NINJA_END_COUNTER "InterFrameNinjaEndCounter"
+#define __MEDIA_USER_FEATURE_VALUE_ENABLE_IFNCC                         "EnableIFNCC"
+#endif  //(_DEBUG || _RELEASE_INTERNAL)
 
 class VpUtils
 {
 public:
-    // it is only be used by vpdata->pVpHalState->CopySurface, will be removed after mediaCopy ready
-    static MOS_SURFACE VpHalConvertVphalSurfaceToMosSurface(PVPHAL_SURFACE surface);
-
-    //!
-    //! \brief    Get the color pack type of a surface
-    //! \details  Map mos surface format to color pack format and return.
-    //!           For unknown format return VPHAL_COLORPACK_UNKNOWN
-    //! \param    [in] format
-    //!           MOS_FORMAT of a surface
-    //! \return   VPHAL_COLORPACK
-    //!           Color pack type of the surface
-    //!
-    static VPHAL_COLORPACK GetSurfaceColorPack(MOS_FORMAT format);
-
-    //!
-    //! \brief    Performs Color Space Convert for Sample 8 bit
-    //! \details  Performs Color Space Convert from Src Color Spase to Dst Color Spase
-    //! \param    [out] pOutput
-    //!           Pointer to VPHAL_COLOR_SAMPLE_8
-    //! \param    [in] pInput
-    //!           Pointer to VPHAL_COLOR_SAMPLE_8
-    //! \param    [in] srcCspace
-    //!           Source Color Space
-    //! \param    [in] dstCspace
-    //!           Dest Color Space
-    //! \return   bool
-    //!           Return true if successful, otherwise false
-    //!
-    static bool GetCscMatrixForRender8Bit(
-        VPHAL_COLOR_SAMPLE_8  *output,
-        VPHAL_COLOR_SAMPLE_8  *input,
-        VPHAL_CSPACE          srcCspace,
-        VPHAL_CSPACE          dstCspace);
-
     //!
     //! \brief    Allocates the Surface
     //! \details  Allocates the Surface
@@ -380,19 +399,31 @@ public:
         float        *fCscInOffset,
         float        *fCscOutOffset);
 
-    //! \brief    Get the bit depth of a surface
-    //! \details  Get bit depth of input mos surface format and return.
-    //!           For unknown format return 0
-    //! \param    [in] format
-    //!           MOS_FORMAT of a surface
-    //! \return   uint32_t
-    //!           Bit depth of the surface
     //!
-    static uint32_t GetSurfaceBitDepth(
-        MOS_FORMAT format);
+    //! \brief    Performs Color Space Convert for Sample 8 bit
+    //! \details  Performs Color Space Convert from Src Color Spase to Dst Color Spase
+    //! \param    [out] pOutput
+    //!           Pointer to VPHAL_COLOR_SAMPLE_8
+    //! \param    [in] pInput
+    //!           Pointer to VPHAL_COLOR_SAMPLE_8
+    //! \param    [in] srcCspace
+    //!           Source Color Space
+    //! \param    [in] dstCspace
+    //!           Dest Color Space
+    //! \return   bool
+    //!           Return true if successful, otherwise false
+    //!
+    static bool GetCscMatrixForRender8Bit(
+        VPHAL_COLOR_SAMPLE_8 *output,
+        VPHAL_COLOR_SAMPLE_8 *input,
+        VPHAL_CSPACE          srcCspace,
+        VPHAL_CSPACE          dstCspace);
 
     static bool IsSyncFreeNeededForMMCSurface(PVPHAL_SURFACE surface, PMOS_INTERFACE osInterface);
 
+    static bool IsVerticalRotation(VPHAL_ROTATION rotation);
+
+private:
     //!
     //! \brief    Performs Color Space Convert for Sample 8 bit Using Specified Coeff Matrix
     //! \details  Performs Color Space Convert from Src Color Spase to Dst Color Spase
@@ -410,7 +441,14 @@ public:
     //! \return   bool
     //!           Return true if successful, otherwise false
     //!
-    static bool GetCscMatrixForRender8BitWithCoeff(VPHAL_COLOR_SAMPLE_8 *output, VPHAL_COLOR_SAMPLE_8 *input, VPHAL_CSPACE srcCspace, VPHAL_CSPACE dstCspace, int32_t *iCscMatrix);
+    static bool GetCscMatrixForRender8BitWithCoeff(
+        VPHAL_COLOR_SAMPLE_8 *output,
+        VPHAL_COLOR_SAMPLE_8 *input,
+        VPHAL_CSPACE          srcCspace,
+        VPHAL_CSPACE          dstCspace,
+        int32_t              *iCscMatrix);
+
+MEDIA_CLASS_DEFINE_END(VpUtils)
 };
 
 #endif // !__VP_UTILS_H__
